@@ -13,7 +13,7 @@
 #include "adw-bidi-private.h"
 #include "adw-macros-private.h"
 
-#define FADE_WIDTH 18.0f
+#define FADE_WIDTH 18
 
 struct _AdwFadingLabel
 {
@@ -76,7 +76,7 @@ ensure_shader (AdwFadingLabel *self)
     /* If shaders aren't supported, the error doesn't matter and we just
      * silently fall back */
     if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED))
-      g_warning ("Couldn't compile shader: %s\n", error->message);
+      g_critical ("Couldn't compile shader: %s\n", error->message);
   }
 
   g_clear_error (&error);
@@ -163,8 +163,6 @@ adw_fading_label_snapshot (GtkWidget   *widget,
                                                             "offsetRight", 0.0f,
                                                             "strengthLeft", align > 0 ? 1.0f : 0.0f,
                                                             "strengthRight", align < 1 ? 1.0f : 0.0f,
-                                                            "widthLeft", FADE_WIDTH,
-                                                            "widthRight", FADE_WIDTH,
                                                             NULL));
   } else {
     gtk_snapshot_push_clip (snapshot, &bounds);
@@ -260,14 +258,18 @@ adw_fading_label_class_init (AdwFadingLabelClass *klass)
   widget_class->unrealize = adw_fading_label_unrealize;
 
   props[PROP_LABEL] =
-    g_param_spec_string ("label", NULL, NULL,
+    g_param_spec_string ("label",
+                         "Label",
+                         "Label",
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   props[PROP_ALIGN] =
-    g_param_spec_float ("align", NULL, NULL,
+    g_param_spec_float ("align",
+                        "Align",
+                        "Align",
                         0.0, 1.0, 0.0,
-                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 }
