@@ -8,14 +8,13 @@
 
 #include "adw-preferences-page-private.h"
 
-#include "adw-macros-private.h"
 #include "adw-preferences-group-private.h"
 #include "adw-widget-utils-private.h"
 
 /**
  * AdwPreferencesPage:
  *
- * A page from [class@PreferencesWindow].
+ * A page from [class@PreferencesDialog].
  *
  * <picture>
  *   <source srcset="preferences-page-dark.png" media="(prefers-color-scheme: dark)">
@@ -32,13 +31,12 @@
  * ## Accessibility
  *
  * `AdwPreferencesPage` uses the `GTK_ACCESSIBLE_ROLE_GROUP` role.
- *
- * Since: 1.0
  */
 
 typedef struct
 {
   GtkBox *box;
+  GtkLabel *description;
   GtkWidget *scrolled_window;
 
   char *icon_name;
@@ -62,6 +60,7 @@ enum {
   PROP_0,
   PROP_ICON_NAME,
   PROP_TITLE,
+  PROP_DESCRIPTION,
   PROP_NAME,
   PROP_USE_UNDERLINE,
   LAST_PROP,
@@ -69,6 +68,14 @@ enum {
 
 static GParamSpec *props[LAST_PROP];
 
+static gboolean
+is_visible_group (GtkWidget *widget,
+                  gpointer   user_data)
+{
+  return ADW_IS_PREFERENCES_GROUP (widget) &&
+         gtk_widget_get_visible (widget);
+}
+
 static void
 adw_preferences_page_get_property (GObject    *object,
                                    guint       prop_id,
@@ -84,6 +91,9 @@ adw_preferences_page_get_property (GObject    *object,
   case PROP_TITLE:
     g_value_set_string (value, adw_preferences_page_get_title (self));
     break;
+  case PROP_DESCRIPTION:
+    g_value_set_string (value, adw_preferences_page_get_description (self));
+    break;
   case PROP_NAME:
     g_value_set_string (value, adw_preferences_page_get_name (self));
     break;
@@ -110,6 +120,9 @@ adw_preferences_page_set_property (GObject      *object,
   case PROP_TITLE:
     adw_preferences_page_set_title (self, g_value_get_string (value));
     break;
+  case PROP_DESCRIPTION:
+    adw_preferences_page_set_description (self, g_value_get_string (value));
+    break;
   case PROP_NAME:
     adw_preferences_page_set_name (self, g_value_get_string (value));
     break;
@@ -124,10 +137,7 @@ adw_preferences_page_set_property (GObject      *object,
 static void
 adw_preferences_page_dispose (GObject *object)
 {
-  AdwPreferencesPage *self = ADW_PREFERENCES_PAGE (object);
-  AdwPreferencesPagePrivate *priv = adw_preferences_page_get_instance_private (self);
-
-  gtk_widget_unparent (priv->scrolled_window);
+  gtk_widget_dispose_template (GTK_WIDGET (object), ADW_TYPE_PREFERENCES_PAGE);
 
   G_OBJECT_CLASS (adw_preferences_page_parent_class)->dispose (object);
 }
@@ -162,13 +172,9 @@ adw_preferences_page_class_init (AdwPreferencesPageClass *klass)
    * AdwPreferencesPage:icon-name: (attributes org.gtk.Property.get=adw_preferences_page_get_icon_name org.gtk.Property.set=adw_preferences_page_set_icon_name)
    *
    * The icon name for this page.
-   *
-   * Since: 1.0
    */
   props[PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name",
-                         "Icon name",
-                         "The icon name for this page",
+    g_param_spec_string ("icon-name", NULL, NULL,
                          "",
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -176,13 +182,21 @@ adw_preferences_page_class_init (AdwPreferencesPageClass *klass)
    * AdwPreferencesPage:title: (attributes org.gtk.Property.get=adw_preferences_page_get_title org.gtk.Property.set=adw_preferences_page_set_title)
    *
    * The title for this page.
-   *
-   * Since: 1.0
    */
   props[PROP_TITLE] =
-    g_param_spec_string ("title",
-                         "Title",
-                         "The title for this page",
+    g_param_spec_string ("title", NULL, NULL,
+                         "",
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * AdwPreferencesPage:description: (attributes org.gtk.Property.get=adw_preferences_page_get_description org.gtk.Property.set=adw_preferences_page_set_description)
+   *
+   * The description to be displayed at the top of the page.
+   * 
+   * Since: 1.4
+   */
+  props[PROP_DESCRIPTION] =
+    g_param_spec_string ("description", NULL, NULL,
                          "",
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -190,13 +204,9 @@ adw_preferences_page_class_init (AdwPreferencesPageClass *klass)
    * AdwPreferencesPage:name: (attributes org.gtk.Property.get=adw_preferences_page_get_name org.gtk.Property.set=adw_preferences_page_set_name)
    *
    * The name of this page.
-   *
-   * Since: 1.0
    */
   props[PROP_NAME] =
-    g_param_spec_string ("name",
-                         "Name",
-                         "The name of this page",
+    g_param_spec_string ("name", NULL, NULL,
                          NULL,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -204,21 +214,18 @@ adw_preferences_page_class_init (AdwPreferencesPageClass *klass)
    * AdwPreferencesPage:use-underline: (attributes org.gtk.Property.get=adw_preferences_page_get_use_underline org.gtk.Property.set=adw_preferences_page_set_use_underline)
    *
    * Whether an embedded underline in the title indicates a mnemonic.
-   *
-   * Since: 1.0
    */
   props[PROP_USE_UNDERLINE] =
-    g_param_spec_boolean ("use-underline",
-                          "Use underline",
-                          " Whether an embedded underline in the title label indicates a mnemonic",
+    g_param_spec_boolean ("use-underline", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-preferences-page.ui");
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesPage, box);
+  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesPage, description);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesPage, scrolled_window);
 
   gtk_widget_class_set_css_name (widget_class, "preferencespage");
@@ -230,6 +237,7 @@ static void
 adw_preferences_page_init (AdwPreferencesPage *self)
 {
   AdwPreferencesPagePrivate *priv = adw_preferences_page_get_instance_private (self);
+
   priv->title = g_strdup ("");
 
   gtk_widget_init_template (GTK_WIDGET (self));
@@ -263,8 +271,6 @@ adw_preferences_page_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwPreferencesPage`.
  *
  * Returns: the newly created `AdwPreferencesPage`
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_preferences_page_new (void)
@@ -272,250 +278,12 @@ adw_preferences_page_new (void)
   return g_object_new (ADW_TYPE_PREFERENCES_PAGE, NULL);
 }
 
-/**
- * adw_preferences_page_get_icon_name: (attributes org.gtk.Method.get_property=icon-name)
- * @self: a preferences page
- *
- * Gets the icon name for @self.
- *
- * Returns: (nullable): the icon name for @self
- *
- * Since: 1.0
- */
-const char *
-adw_preferences_page_get_icon_name (AdwPreferencesPage *self)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  return priv->icon_name;
-}
-
-/**
- * adw_preferences_page_set_icon_name: (attributes org.gtk.Method.set_property=icon-name)
- * @self: a preferences page
- * @icon_name: (nullable): the icon name
- *
- * Sets the icon name for @self.
- *
- * Since: 1.0
- */
-void
-adw_preferences_page_set_icon_name (AdwPreferencesPage *self,
-                                    const char         *icon_name)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  if (g_strcmp0 (priv->icon_name, icon_name) == 0)
-    return;
-
-  g_clear_pointer (&priv->icon_name, g_free);
-  priv->icon_name = g_strdup (icon_name);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ICON_NAME]);
-}
-
-/**
- * adw_preferences_page_get_title: (attributes org.gtk.Method.get_property=title)
- * @self: a preferences page
- *
- * Gets the title of @self.
- *
- * Returns: the title of @self.
- *
- * Since: 1.0
- */
-const char *
-adw_preferences_page_get_title (AdwPreferencesPage *self)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  return priv->title;
-}
-
-/**
- * adw_preferences_page_set_title: (attributes org.gtk.Method.set_property=title)
- * @self: a preferences page
- * @title: the title
- *
- * Sets the title of @self.
- *
- * Since: 1.0
- */
-void
-adw_preferences_page_set_title (AdwPreferencesPage *self,
-                                const char         *title)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  if (g_strcmp0 (priv->title, title) == 0)
-    return;
-
-  g_clear_pointer (&priv->title, g_free);
-  priv->title = g_strdup (title ? title : "");
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE]);
-}
-
-/**
- * adw_preferences_page_get_name: (attributes org.gtk.Method.get_property=name)
- * @self: a preferences page
- *
- * Gets the name of @self.
- *
- * Returns: (nullable): the name of @self
- *
- * Since: 1.0
- */
-const char *
-adw_preferences_page_get_name (AdwPreferencesPage *self)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  return priv->name;
-}
-
-/**
- * adw_preferences_page_set_name: (attributes org.gtk.Method.set_property=name)
- * @self: a preferences page
- * @name: (nullable): the name
- *
- * Sets the name of @self.
- *
- * Since: 1.0
- */
-void
-adw_preferences_page_set_name (AdwPreferencesPage *self,
-                               const char         *name)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  if (g_strcmp0(priv->name, name) == 0)
-    return;
-
-  g_clear_pointer (&priv->name, g_free);
-  priv->name = g_strdup (name);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_NAME]);
-}
-
-/**
- * adw_preferences_page_get_rows:
- * @self: a preferences page
- *
- * Gets a [iface@Gio.ListModel] that contains the rows of the page.
- *
- * This can be used to keep an up-to-date view.
- *
- * Returns: (transfer full): a list model for the page's rows
- *
- * Since: 1.0
- */
-GListModel *
-adw_preferences_page_get_rows (AdwPreferencesPage *self)
-{
-  AdwPreferencesPagePrivate *priv;
-  GListModel *model;
-  GtkExpression *expr;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  expr = gtk_property_expression_new (GTK_TYPE_WIDGET, NULL, "visible");
-
-  model = gtk_widget_observe_children (GTK_WIDGET (priv->box));
-  model = G_LIST_MODEL (gtk_filter_list_model_new (model, GTK_FILTER (gtk_bool_filter_new (expr))));
-  model = G_LIST_MODEL (gtk_map_list_model_new (model,
-                                                (GtkMapListModelMapFunc) adw_preferences_group_get_rows,
-                                                NULL,
-                                                NULL));
-
-  return G_LIST_MODEL (gtk_flatten_list_model_new (model));
-}
-
-/**
- * adw_preferences_page_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
- * @self: a preferences page
- *
- * Gets whether an embedded underline in the title indicates a mnemonic.
- *
- * Returns: whether an embedded underline in the title indicates a mnemonic
- *
- * Since: 1.0
- */
-gboolean
-adw_preferences_page_get_use_underline (AdwPreferencesPage *self)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), FALSE);
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  return priv->use_underline;
-}
-
-/**
- * adw_preferences_page_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
- * @self: a preferences page
- * @use_underline: `TRUE` if underlines in the text indicate mnemonics
- *
- * Sets whether an embedded underline in the title indicates a mnemonic.
- *
- * Since: 1.0
- */
-void
-adw_preferences_page_set_use_underline (AdwPreferencesPage *self,
-                                        gboolean           use_underline)
-{
-  AdwPreferencesPagePrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
-
-  priv = adw_preferences_page_get_instance_private (self);
-
-  use_underline = !!use_underline;
-
-  if (priv->use_underline == use_underline)
-    return;
-
-  priv->use_underline = use_underline;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_USE_UNDERLINE]);
-}
-
 /**
  * adw_preferences_page_add:
  * @self: a preferences page
  * @group: the group to add
  *
  * Adds a preferences group to @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_page_add (AdwPreferencesPage  *self,
@@ -537,8 +305,6 @@ adw_preferences_page_add (AdwPreferencesPage  *self,
  * @group: the group to remove
  *
  * Removes a group from @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_page_remove (AdwPreferencesPage  *self,
@@ -556,3 +322,295 @@ adw_preferences_page_remove (AdwPreferencesPage  *self,
   else
     ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, group);
 }
+
+/**
+ * adw_preferences_page_get_icon_name: (attributes org.gtk.Method.get_property=icon-name)
+ * @self: a preferences page
+ *
+ * Gets the icon name for @self.
+ *
+ * Returns: (nullable): the icon name for @self
+ */
+const char *
+adw_preferences_page_get_icon_name (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  return priv->icon_name;
+}
+
+/**
+ * adw_preferences_page_set_icon_name: (attributes org.gtk.Method.set_property=icon-name)
+ * @self: a preferences page
+ * @icon_name: (nullable): the icon name
+ *
+ * Sets the icon name for @self.
+ */
+void
+adw_preferences_page_set_icon_name (AdwPreferencesPage *self,
+                                    const char         *icon_name)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  if (!g_set_str (&priv->icon_name, icon_name))
+    return;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ICON_NAME]);
+}
+
+/**
+ * adw_preferences_page_get_title: (attributes org.gtk.Method.get_property=title)
+ * @self: a preferences page
+ *
+ * Gets the title of @self.
+ *
+ * Returns: the title of @self.
+ */
+const char *
+adw_preferences_page_get_title (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  return priv->title;
+}
+
+/**
+ * adw_preferences_page_set_title: (attributes org.gtk.Method.set_property=title)
+ * @self: a preferences page
+ * @title: the title
+ *
+ * Sets the title of @self.
+ */
+void
+adw_preferences_page_set_title (AdwPreferencesPage *self,
+                                const char         *title)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  if (!g_set_str (&priv->title, title ? title : ""))
+    return;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE]);
+}
+
+/**
+ * adw_preferences_page_get_description: (attributes org.gtk.Method.get_property=description)
+ * @self: a preferences page
+ *
+ * Gets the description of @self.
+ *
+ * Returns: the description of @self.
+ * 
+ * Since: 1.4
+ */
+const char *
+adw_preferences_page_get_description (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  return gtk_label_get_text (priv->description);
+}
+
+/**
+ * adw_preferences_page_set_description: (attributes org.gtk.Method.set_property=description)
+ * @self: a preferences page
+ * @description: the description
+ *
+ * Sets the description of @self.
+ * 
+ * The description is displayed at the top of the page.
+ * 
+ * Since: 1.4
+ */
+void
+adw_preferences_page_set_description (AdwPreferencesPage *self,
+                                      const char         *description)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  if (g_strcmp0 (gtk_label_get_label (priv->description), description) == 0)
+    return;
+
+  gtk_label_set_label (priv->description, description);
+  gtk_widget_set_visible (GTK_WIDGET (priv->description),
+                          description && *description);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_DESCRIPTION]);
+}
+
+/**
+ * adw_preferences_page_get_name: (attributes org.gtk.Method.get_property=name)
+ * @self: a preferences page
+ *
+ * Gets the name of @self.
+ *
+ * Returns: (nullable): the name of @self
+ */
+const char *
+adw_preferences_page_get_name (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  return priv->name;
+}
+
+/**
+ * adw_preferences_page_set_name: (attributes org.gtk.Method.set_property=name)
+ * @self: a preferences page
+ * @name: (nullable): the name
+ *
+ * Sets the name of @self.
+ */
+void
+adw_preferences_page_set_name (AdwPreferencesPage *self,
+                               const char         *name)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  if (!g_set_str (&priv->name, name))
+    return;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_NAME]);
+}
+
+/**
+ * adw_preferences_page_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
+ * @self: a preferences page
+ *
+ * Gets whether an embedded underline in the title indicates a mnemonic.
+ *
+ * Returns: whether an embedded underline in the title indicates a mnemonic
+ */
+gboolean
+adw_preferences_page_get_use_underline (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), FALSE);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  return priv->use_underline;
+}
+
+/**
+ * adw_preferences_page_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
+ * @self: a preferences page
+ * @use_underline: `TRUE` if underlines in the text indicate mnemonics
+ *
+ * Sets whether an embedded underline in the title indicates a mnemonic.
+ */
+void
+adw_preferences_page_set_use_underline (AdwPreferencesPage *self,
+                                        gboolean           use_underline)
+{
+  AdwPreferencesPagePrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  use_underline = !!use_underline;
+
+  if (priv->use_underline == use_underline)
+    return;
+
+  priv->use_underline = use_underline;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_USE_UNDERLINE]);
+}
+
+static GListModel *
+preferences_group_to_rows (AdwPreferencesGroup *group)
+{
+  g_object_unref (group);
+
+  return adw_preferences_group_get_rows (group);
+}
+
+/**
+ * adw_preferences_page_get_rows:
+ * @self: a preferences page
+ *
+ * Gets a [iface@Gio.ListModel] that contains the rows of the page.
+ *
+ * This can be used to keep an up-to-date view.
+ *
+ * Returns: (transfer full): a list model for the page's rows
+ */
+GListModel *
+adw_preferences_page_get_rows (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+  GListModel *model;
+  GtkCustomFilter *filter;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_PAGE (self), NULL);
+
+  priv = adw_preferences_page_get_instance_private (self);
+
+  filter = gtk_custom_filter_new ((GtkCustomFilterFunc) is_visible_group, NULL, NULL);
+
+  model = gtk_widget_observe_children (GTK_WIDGET (priv->box));
+  model = G_LIST_MODEL (gtk_filter_list_model_new (model, GTK_FILTER (filter)));
+  model = G_LIST_MODEL (gtk_map_list_model_new (model,
+                                                (GtkMapListModelMapFunc) preferences_group_to_rows,
+                                                NULL,
+                                                NULL));
+
+  return G_LIST_MODEL (gtk_flatten_list_model_new (model));
+}
+
+/**
+ * adw_preferences_page_scroll_to_top:
+ * @self: a preferences page
+ *
+ * Scrolls the scrolled window of @self to the top.
+ *
+ * Since: 1.3
+ */
+void
+adw_preferences_page_scroll_to_top (AdwPreferencesPage *self)
+{
+  AdwPreferencesPagePrivate *priv;
+  GtkAdjustment *adjustment;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_PAGE (self));
+
+  priv = adw_preferences_page_get_instance_private (self);
+  adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->scrolled_window));
+
+  gtk_adjustment_set_value (adjustment, gtk_adjustment_get_lower (adjustment));
+}
