@@ -7,8 +7,8 @@
 
 #include "config.h"
 
+#include "adw-macros-private.h"
 #include "adw-view-switcher-title.h"
-
 #include "adw-squeezer.h"
 #include "adw-window-title.h"
 
@@ -43,17 +43,17 @@
  *
  * ```xml
  * <object class="GtkWindow">
- *   <property name="titlebar">
+ *   <child type="titlebar">
  *     <object class="AdwHeaderBar">
  *       <property name="centering-policy">strict</property>
- *       <property name="title-widget">
+ *       <child type="title">
  *         <object class="AdwViewSwitcherTitle" id="title">
  *           <property name="stack">stack</property>
  *         </object>
- *       </property>
+ *       </child>
  *     </object>
- *   </property>
- *   <property name="child">
+ *   </child>
+ *   <child>
  *     <object class="GtkBox">
  *       <property name="orientation">vertical</property>
  *       <child>
@@ -68,13 +68,15 @@
  *         </object>
  *       </child>
  *     </object>
- *   </property>
+ *   </child>
  * </object>
  * ```
  *
  * ## CSS nodes
  *
  * `AdwViewSwitcherTitle` has a single CSS node with name `viewswitchertitle`.
+ *
+ * Since: 1.0
  */
 
 enum {
@@ -206,12 +208,11 @@ adw_view_switcher_title_dispose (GObject *object)
 {
   AdwViewSwitcherTitle *self = ADW_VIEW_SWITCHER_TITLE (object);
 
-  if (self->pages) {
+  if (self->pages)
     g_signal_handlers_disconnect_by_func (self->pages, G_CALLBACK (update_view_switcher_visible), self);
-    g_clear_object (&self->pages);
-  }
 
-  gtk_widget_dispose_template (GTK_WIDGET (self), ADW_TYPE_VIEW_SWITCHER_TITLE);
+  if (self->squeezer)
+    gtk_widget_unparent (GTK_WIDGET (self->squeezer));
 
   G_OBJECT_CLASS (adw_view_switcher_title_parent_class)->dispose (object);
 }
@@ -283,36 +284,48 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    * AdwViewSwitcherTitle:stack: (attributes org.gtk.Property.get=adw_view_switcher_title_get_stack org.gtk.Property.set=adw_view_switcher_title_set_stack)
    *
    * The stack the view switcher controls.
+   *
+   * Since: 1.0
    */
   props[PROP_STACK] =
-    g_param_spec_object ("stack", NULL, NULL,
+    g_param_spec_object ("stack",
+                         "Stack",
+                         "The stack the view switcher controls",
                          ADW_TYPE_VIEW_STACK,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwViewSwitcherTitle:title: (attributes org.gtk.Property.get=adw_view_switcher_title_get_title org.gtk.Property.set=adw_view_switcher_title_set_title)
    *
    * The title to display.
    *
-   * The title typically identifies the current view or content item, and
-   * generally does not use the application name.
+   * The title should give a user additional details. A good title should not
+   * include the application name.
+   *
+   * Since: 1.0
    */
   props[PROP_TITLE] =
-    g_param_spec_string ("title", NULL, NULL,
+    g_param_spec_string ("title",
+                         "Title",
+                         "The title to display",
                          "",
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwViewSwitcherTitle:subtitle: (attributes org.gtk.Property.get=adw_view_switcher_title_get_subtitle org.gtk.Property.set=adw_view_switcher_title_set_subtitle)
    *
    * The subtitle to display.
    *
-   * The subtitle should give the user additional details.
+   * The subtitle should give a user additional details.
+   *
+   * Since: 1.0
    */
   props[PROP_SUBTITLE] =
-    g_param_spec_string ("subtitle", NULL, NULL,
+    g_param_spec_string ("subtitle",
+                         "Subtitle",
+                         "The subtitle to display",
                          "",
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwViewSwitcherTitle:view-switcher-enabled: (attributes org.gtk.Property.get=adw_view_switcher_title_get_view_switcher_enabled org.gtk.Property.set=adw_view_switcher_title_set_view_switcher_enabled)
@@ -325,11 +338,15 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    *
    * This can be used e.g. to ensure the view switcher is hidden below a certain
    * window width, or any other constraint you find suitable.
+   *
+   * Since: 1.0
    */
   props[PROP_VIEW_SWITCHER_ENABLED] =
-    g_param_spec_boolean ("view-switcher-enabled", NULL, NULL,
+    g_param_spec_boolean ("view-switcher-enabled",
+                         "View switcher enabled",
+                         "Whether the view switcher is enabled",
                          TRUE,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwViewSwitcherTitle:title-visible: (attributes org.gtk.Property.get=adw_view_switcher_title_get_title_visible)
@@ -338,11 +355,15 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    *
    * If the title is visible, it means the view switcher is hidden an it may be
    * wanted to show an alternative switcher, e.g. a [class@ViewSwitcherBar].
+   *
+   * Since: 1.0
    */
   props[PROP_TITLE_VISIBLE] =
-    g_param_spec_boolean ("title-visible", NULL, NULL,
+    g_param_spec_boolean ("title-visible",
+                         "Title visible",
+                         "Whether the title is currently visible",
                          TRUE,
-                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -377,6 +398,8 @@ adw_view_switcher_title_init (AdwViewSwitcherTitle *self)
  * Creates a new `AdwViewSwitcherTitle`.
  *
  * Returns: the newly created `AdwViewSwitcherTitle`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_view_switcher_title_new (void)
@@ -391,6 +414,8 @@ adw_view_switcher_title_new (void)
  * Gets the stack controlled by @self.
  *
  * Returns: (nullable) (transfer none): the stack
+ *
+ * Since: 1.0
  */
 AdwViewStack *
 adw_view_switcher_title_get_stack (AdwViewSwitcherTitle *self)
@@ -406,6 +431,8 @@ adw_view_switcher_title_get_stack (AdwViewSwitcherTitle *self)
  * @stack: (nullable): a stack
  *
  * Sets the stack controlled by @self.
+ *
+ * Since: 1.0
  */
 void
 adw_view_switcher_title_set_stack (AdwViewSwitcherTitle *self,
@@ -447,6 +474,8 @@ adw_view_switcher_title_set_stack (AdwViewSwitcherTitle *self,
  * Gets the title of @self.
  *
  * Returns: the title
+ *
+ * Since: 1.0
  */
 const char *
 adw_view_switcher_title_get_title (AdwViewSwitcherTitle *self)
@@ -463,8 +492,7 @@ adw_view_switcher_title_get_title (AdwViewSwitcherTitle *self)
  *
  * Sets the title of @self.
  *
- * The title typically identifies the current view or content item, and
- * generally does not use the application name.
+ * Since: 1.0
  */
 void
 adw_view_switcher_title_set_title (AdwViewSwitcherTitle *self,
@@ -487,6 +515,8 @@ adw_view_switcher_title_set_title (AdwViewSwitcherTitle *self,
  * Gets the subtitle of @self.
  *
  * Returns: the subtitle
+ *
+ * Since: 1.0
  */
 const char *
 adw_view_switcher_title_get_subtitle (AdwViewSwitcherTitle *self)
@@ -503,7 +533,7 @@ adw_view_switcher_title_get_subtitle (AdwViewSwitcherTitle *self)
  *
  * Sets the subtitle of @self.
  *
- * The subtitle should give the user additional details.
+ * Since: 1.0
  */
 void
 adw_view_switcher_title_set_subtitle (AdwViewSwitcherTitle *self,
@@ -526,6 +556,8 @@ adw_view_switcher_title_set_subtitle (AdwViewSwitcherTitle *self,
  * Gets whether @self's view switcher is enabled.
  *
  * Returns: whether the view switcher is enabled
+ *
+ * Since: 1.0
  */
 gboolean
 adw_view_switcher_title_get_view_switcher_enabled (AdwViewSwitcherTitle *self)
@@ -542,12 +574,7 @@ adw_view_switcher_title_get_view_switcher_enabled (AdwViewSwitcherTitle *self)
  *
  * Sets whether @self's view switcher is enabled.
  *
- * If it is disabled, the title will be displayed instead. This allows to
- * programmatically hide the view switcher even if it fits in the available
- * space.
- *
- * This can be used e.g. to ensure the view switcher is hidden below a certain
- * window width, or any other constraint you find suitable.
+ * Since: 1.0
  */
 void
 adw_view_switcher_title_set_view_switcher_enabled (AdwViewSwitcherTitle *self,
@@ -572,10 +599,9 @@ adw_view_switcher_title_set_view_switcher_enabled (AdwViewSwitcherTitle *self,
  *
  * Gets whether the title of @self is currently visible.
  *
- * If the title is visible, it means the view switcher is hidden an it may be
- * wanted to show an alternative switcher, e.g. a [class@ViewSwitcherBar].
- *
  * Returns: whether the title of @self is currently visible
+ *
+ * Since: 1.0
  */
 gboolean
 adw_view_switcher_title_get_title_visible (AdwViewSwitcherTitle *self)
